You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by bm...@apache.org on 2015/10/22 01:03:15 UTC

mesos git commit: Renamed Framework::cleanupConnection to Framework::disconnect.

Repository: mesos
Updated Branches:
  refs/heads/master 0afa64434 -> 837a13f3b


Renamed Framework::cleanupConnection to Framework::disconnect.


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/837a13f3
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/837a13f3
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/837a13f3

Branch: refs/heads/master
Commit: 837a13f3b8912f3bc847afecff7bfd06536414aa
Parents: 0afa644
Author: Benjamin Mahler <be...@gmail.com>
Authored: Wed Oct 21 14:45:14 2015 -0700
Committer: Benjamin Mahler <be...@gmail.com>
Committed: Wed Oct 21 14:58:02 2015 -0700

----------------------------------------------------------------------
 src/master/master.hpp | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/837a13f3/src/master/master.hpp
----------------------------------------------------------------------
diff --git a/src/master/master.hpp b/src/master/master.hpp
index e7b16fd..3aa7017 100644
--- a/src/master/master.hpp
+++ b/src/master/master.hpp
@@ -1484,7 +1484,7 @@ struct Framework
   ~Framework()
   {
     if (http.isSome()) {
-      cleanupConnection();
+      closeHttpConnection();
     }
   }
 
@@ -1724,7 +1724,7 @@ struct Framework
     // Cleanup the HTTP connnection if this is a downgrade from HTTP
     // to PID. Note that the connection may already be closed.
     if (http.isSome()) {
-      cleanupConnection();
+      closeHttpConnection();
     }
 
     // TODO(benh): unlink(oldPid);
@@ -1742,7 +1742,7 @@ struct Framework
       // Note that master creates a new HTTP connection for every
       // subscribe request, so 'newHttp' should always be different
       // from 'http'.
-      cleanupConnection();
+      closeHttpConnection();
     }
 
     CHECK_NONE(http);
@@ -1750,10 +1750,11 @@ struct Framework
     http = newHttp;
   }
 
   // Closes the connection and stops the heartbeat.
   // TODO(vinod): Currently 'connected' variable is set separately
   // from this method. We need to make sure these are in sync.
-  void cleanupConnection()
+  void closeHttpConnection()
   {
     CHECK_SOME(http);
@@ -1750,10 +1750,11 @@ struct Framework
   }
 
-  // Closes the connection and stops the heartbeat.
+  // Closes the HTTP connection and stops the heartbeat.
+  //
   // TODO(vinod): Currently 'connected' variable is set separately
   // from this method. We need to make sure these are in sync.